## This file is part of the FuzzyStatProb library.
##
## Copyright 2012 Pablo J. Villacorta
##
##
## This package is free software: you can redistribute it and/or modify
## it under the terms of the GNU Lesser General Public License as published by
## the Free Software Foundation, either version 3 of the License, or
## (at your option) any later version.
##

.onAttach <- function(lib, pkg)
{
   packageStartupMessage("FuzzyStatProb by Pablo J. Villacorta, Univ. of Granada (Spain) - pjvi@decsai.ugr.es");
}
